# Copyright (C) 2004 Gregoire Lejeune <gregoire.lejeune@free.fr>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA

module Constants
  RGV_VERSION = "0.8.0"
  RGV_DATE = "2007-05-15"
  
  ## Const: Output formats
  FORMATS = [
    "dot", 
    "ps", 
    "mif", 
    "hpgl", 
    "pcl", 
    "gif", 
    "imap", 
    "ismap", 
    "cmap", 
    "jpeg", 
    "png", 
    "xpm", 
    "pic", 
    "gd", 
    "gd2", 
    "wbmp", 
    "vrml", 
    "vtx", 
    "mp", 
    "fig", 
    "svg", 
    "plain", 
    "text", 
    "canon",
    "none"
  ]

  ## Const: programs
  PROGRAMS = [
    "dot",
    "neato",
    "twopi",
    "fdp"
  ]

  ## Const: type de graphs
  GRAPHTYPE = [
    "digraph",
	  "graph"
  ]

  # E, N, G, S and C represent edges, nodes, the root graph, subgraphs and cluster subgraphs, respectively
  GENCS_ATTRS = {
    "Damping"         => { "UseBy" => "G",    "Type" => "double" },
    "K"               => { "UseBy" => "GC",   "Tyep" => "double" },
    "URL"             => { "UseBy" => "ENGC", "Type" => "escString, string" },
    "arrowhead"       => { "UseBy" => "E",    "Type" => "arrowType" },
    "arrowsize"       => { "UseBy" => "E",    "Type" => "double" },
    "arrowtail"       => { "UseBy" => "E",    "Type" => "arrowType" },
    "bb"              => { "UseBy" => "G",    "Type" => "rect" },
    "bgcolor"         => { "UseBy" => "GC",   "Type" => "color" },
    "bottomlabel"     => { "UseBy" => "N",    "Type" => "string" },
    "center"          => { "UseBy" => "G",    "Type" => "bool" },
    "charset"         => { "UseBy" => "G",    "Type" => "string" },
    "clusterrank"     => { "UseBy" => "G",    "Type" => "clusterMode" },
    "color"           => { "UseBy" => "ENC",  "Type" => "color, colorList" },
    "colorscheme"     => { "UseBy" => "ENCG", "Type" => "string" },
    "comment"         => { "UseBy" => "ENG",  "Type" => "string" },             
    "compound"        => { "UseBy" => "G",    "Type" => "bool" },
    "concentrate"     => { "UseBy" => "G",    "Type" => "bool" },
    "constraint"      => { "UseBy" => "E",    "Type" => "bool" },
    "decorate"        => { "UseBy" => "E",    "Type" => "bool" },
    "defaultdist"     => { "UseBy" => "G",    "Type" => "double" },
    "dim"             => { "UseBy" => "G",    "Type" => "int" },
    "dir"             => { "UseBy" => "E",    "Type" => "dirType" },
  "diredgeconstraints"=> { "UseBy" => "N",    "Type" => "double" },
    "distortion"      => { "UseBy" => "N",    "Type" => "double" },
    "dpi"             => { "UseBy" => "G",    "Type" => "double" },
    "edgeURL"         => { "UseBy" => "E",    "Type" => "lblString" },
    "edgehref"        => { "UseBy" => "E",    "Type" => "lblString" },
    "edgetarget"      => { "UseBy" => "E",    "Type" => "escString" },
    "edgetooltip"     => { "UseBy" => "E",    "Type" => "escString" },
    "epsilon"         => { "UseBy" => "G",    "Type" => "double" },
    "esep"            => { "UseBy" => "G",    "Type" => "double" },
    "fillcolor"       => { "UseBy" => "NC",   "Type" => "color" },
    "fixedsize"       => { "UseBy" => "N",    "Type" => "bool" },
    "fontcolor"       => { "UseBy" => "ENGC", "Type" => "color" },
    "fontname"        => { "UseBy" => "ENGC", "Type" => "string" },
    "fontpath"        => { "UseBy" => "G",    "Type" => "string" },
    "fontsize"        => { "UseBy" => "ENGC", "Type" => "double" },
    "group"           => { "UseBy" => "N",    "Type" => "string" },
    "headURL"         => { "UseBy" => "E",    "Type" => "escString" },
    "headclip"        => { "UseBy" => "E",    "Type" => "bool" },
    "headhref"        => { "UseBy" => "E",    "Type" => "escString" },
    "headlabel"       => { "UseBy" => "E",    "Type" => "lblString" },
    "headport"        => { "UseBy" => "E",    "Type" => "portPos" },
    "headtarget"      => { "UseBy" => "E",    "Type" => "escString" },
    "headtooltip"     => { "UseBy" => "E",    "Type" => "escString" },
    "height"          => { "UseBy" => "N",    "Type" => "double" },
    "href"            => { "UseBy" => "E",    "Type" => "lblString" },
    "html"            => { "UseBy" => "N",    "Type" => "lblString" }, # API extension
    "labelURL"        => { "UseBy" => "E",    "Type" => "double" },
    "labelangle"      => { "UseBy" => "E",    "Type" => "double" },
    "labeldistance"   => { "UseBy" => "E",    "Type" => "double" },
    "labelfloat"      => { "UseBy" => "E",    "Type" => "bool" },
    "labelfontcolor"  => { "UseBy" => "E",    "Type" => "color" },
    "labelfontname"   => { "UseBy" => "E",    "Type" => "string" },
    "labelfontsize"   => { "UseBy" => "E",    "Type" => "double" },
    "labelhref"       => { "UseBy" => "E",    "Type" => "double" },
    "labeljust"       => { "UseBy" => "GC",   "Type" => "string" },
    "labelloc"        => { "UseBy" => "GC",   "Type" => "string" },
    "labeltarget"     => { "UseBy" => "E",    "Type" => "escString" },
    "labeltooltip"    => { "UseBy" => "E",    "Type" => "escString" },
    "landscape"       => { "UseBy" => "G",    "Type" => "bool" },
    "layer"           => { "UseBy" => "EN",   "Type" => "layerRange" },
    "layers"          => { "UseBy" => "G",    "Type" => "layerList" },
    "layersep"        => { "UseBy" => "G",    "Type" => "string" },
    "len"             => { "UseBy" => "E",    "Type" => "double" },
    "levelsgap"       => { "UseBy" => "G",    "Type" => "double" },
    "lhead"           => { "UseBy" => "E",    "Type" => "string" },
    "lp"              => { "UseBy" => "EGC",  "Type" => "point" },
    "ltail"           => { "UseBy" => "E",    "Type" => "string" },
    "margin"          => { "UseBy" => "NG",   "Type" => "double, pointf" },
    "maxiter"         => { "UseBy" => "G",    "Type" => "int" },
    "mclimit"         => { "UseBy" => "G",    "Type" => "double" },
    "mindist"         => { "UseBy" => "G",    "Type" => "double" },
    "minlen"          => { "UseBy" => "E",    "Type" => "int" },
    "mode"            => { "UseBy" => "G",    "Type" => "string" },
    "model"           => { "UseBy" => "G",    "Type" => "string" },
    "mosek"           => { "UseBy" => "G",    "Type" => "bool" },
    "nodesep"         => { "UseBy" => "G",    "Type" => "double" },
    "nojustify"       => { "UseBy" => "GCNE", "Type" => "bool" },
    "normalize"       => { "UseBy" => "G",    "Type" => "bool" },
    "nslimit"         => { "UseBy" => "G",    "Type" => "double" },
    "nslimit1"        => { "UseBy" => "G",    "Type" => "double" },
    "ordering"        => { "UseBy" => "G",    "Type" => "string" },
    "orientation"     => { "UseBy" => "N",    "Type" => "double" },
    "orientation"     => { "UseBy" => "G",    "Type" => "string" },
    "outputorder"     => { "UseBy" => "G",    "Type" => "outputMode" },
    "overlap"         => { "UseBy" => "G",    "Type" => "string, bool" },
    "pack"            => { "UseBy" => "G",    "Type" => "bool, int" },
    "packmode"        => { "UseBy" => "G",    "Type" => "packMode" },
    "pad"             => { "UseBy" => "G",    "Type" => "double, pointf" },
    "page"            => { "UseBy" => "G",    "Type" => "pointf" },
    "pagedir"         => { "UseBy" => "G",    "Type" => "pagedir" },
    "pencolor"        => { "UseBy" => "C",    "Type" => "color" },
    "peripheries"     => { "UseBy" => "NC",   "Type" => "int" },
    "pin"             => { "UseBy" => "N",    "Type" => "bool" },
    "pos"             => { "UseBy" => "EN",   "Type" => "point, splineType" },
    "quantum"         => { "UseBy" => "G",    "Type" => "double" },
    "rank"            => { "UseBy" => "S",    "Type" => "rankType" },
    "rankdir"         => { "UseBy" => "G",    "Type" => "rankdir" },
    "ranksep"         => { "UseBy" => "G",    "Type" => "double" },
    "ratio"           => { "UseBy" => "G",    "Type" => "double, string" },
    "rects"           => { "UseBy" => "N",    "Type" => "rect" },
    "regular"         => { "UseBy" => "N",    "Type" => "bool" },
    "remincross"      => { "UseBy" => "G",    "Type" => "bool" },
    "resolution"      => { "UseBy" => "G",    "Type" => "double" },
    "root"            => { "UseBy" => "GN",   "Type" => "string, bool" },
    "rotate"          => { "UseBy" => "G",    "Type" => "int" },
    "samehead"        => { "UseBy" => "E",    "Type" => "string" },
    "sametail"        => { "UseBy" => "E",    "Type" => "string" },
    "samplepoints"    => { "UseBy" => "G",    "Type" => "int" },
    "searchsize"      => { "UseBy" => "G",    "Type" => "int" },
    "sep"             => { "UseBy" => "G",    "Type" => "double, pointf" },
    "shape"           => { "UseBy" => "N",    "Type" => "shape" },
    "shapefile"       => { "UseBy" => "N",    "Type" => "string" },
    "showboxes"       => { "UseBy" => "ENG",  "Type" => "int" },
    "sides"           => { "UseBy" => "N",    "Type" => "int" },
    "size"            => { "UseBy" => "G",    "Type" => "pointf" },
    "skew"            => { "UseBy" => "N",    "Type" => "double" },
    "splines"         => { "UseBy" => "G",    "Type" => "bool, string" },
    "start"           => { "UseBy" => "G",    "Type" => "startType" },
    "style"           => { "UseBy" => "ENC",  "Type" => "style" },
    "stylesheet"      => { "UseBy" => "G",    "Type" => "string" },
    "tailURL"         => { "UseBy" => "E",    "Type" => "escString" },
    "tailclip"        => { "UseBy" => "E",    "Type" => "bool" },
    "tailhref"        => { "UseBy" => "E",    "Type" => "escString" },
    "taillabel"       => { "UseBy" => "E",    "Type" => "lblString" },
    "tailport"        => { "UseBy" => "E",    "Type" => "portPos" },
    "tailtarget"      => { "UseBy" => "E",    "Type" => "escString" },
    "tailtooltip"     => { "UseBy" => "E",    "Type" => "escString" },
    "target"          => { "UseBy" => "ENGC", "Type" => "escString, string" },
    "tooltip"         => { "UseBy" => "NE",   "Type" => "escString" },
    "toplabel"        => { "UseBy" => "N",    "Type" => "string" },
    "truecolor"       => { "UseBy" => "G",    "Type" => "bool" },
    "vertices"        => { "UseBy" => "N",    "Type" => "pointfList" },
    "viewport"        => { "UseBy" => "G",    "Type" => "viewPort" },
    "voro_margin"     => { "UseBy" => "G",    "Type" => "double" },
    "weight"          => { "UseBy" => "E",    "Type" => "double" },
    "width"           => { "UseBy" => "N",    "Type" => "double" },
    "z"               => { "UseBy" => "N",    "Type" => "double" } 
  }

  ## Const: Graph attributs
  GRAPHSATTRS = [
    "Damping",
    "K",
    "URL",
    "bb",
    "bgcolor",
    "center",
    "charset",
    "clusterrank",
    "color",
    "colorscheme",
    "comment",
    "compound",
    "concentrate",
    "defaultdist",
    "dim",
    "diredgeconstraints",
    "dpi",
    "epsilon",
    "esep",
    "fillcolor",
    "fontcolor",
    "fontname",
    "fontnames",
    "fontpath",
    "fontsize",
    "label",
    "labeljust",
    "labelloc",
    "landscape",
    "layer",
    "layers",
    "layersep",
    "lp",
    "margin",
    "maxiter",
    "mclimit",
    "mindist",
    "mode",
    "model",
    "mosek",
    "nodesep",
    "nojustify",
    "normalize",
    "nslimit",
    "nslimit1",
    "ordering",
    "orientation",
    "outputorder",
    "overlap",
    "pack",
    "packmode",
    "pad",
    "page",
    "pagedir",
    "pencolor",
    "peripheries",
    "quantum",
    "rank",
    "rankdir",
    "ranksep",
    "ratio",
    "remincross",
    "resolution",
    "root",
    "rotate",
    "samplepoints",
    "searchsize",
    "sep",
    "showboxes",
    "size",
    "splines",
    "start",
    "style",
    "stylesheet",
    "target",
    "tooltip",
    "truecolor",
    "viewport",
    "voro_margin"
  ]

  ## Const: Node attributs
  NODESATTRS = [
    "URL",
    "bottomlabel",
    "color",
    "colorscheme",
    "comment",
    "distortion",
    "fillcolor",
    "fixedsize",
    "fontcolor",
    "fontname",
    "fontsize",
    "group",
    "height",
    "label", "html", 
    "layer",
    "margin",
    "nojustify",
    "orientation",
    "peripheries",
    "pin",
    "pos",
    "rects",
    "regular",
    "root",
    "samplepoints",
    "shape",
    "shapefile",
    "sides",
    "skew",
    "style",
    "target",
    "tooltip",
    #"toplabel", 
    #does not appear to be an option according to attributes info
    "vertices",
    "width",
    "z"
  ]

  ## Const: Edge attributs
  EDGESATTRS = [
    "arrowhead",
    "arrowsize",
    "arrowtail",
    "color",
    "colorscheme",
    "comment",
    "constraint",
    "decorate",
    "dir",
    "edgeURL",
    "edgehref",
    "edgetarget",
    "edgetooltip",
    "fontcolor",
    "fontname",
    "fontsize",
    "headURL",
    "headclip",
    "headhref",
    "headlabel",
    "headport",
    "headtarget",
    "headtooltip",
    "href",
    "label",
    "labelURL",
    "labelangle",
    "labeldistance",
    "labelfloat",
    "labelfontcolor",
    "labelfontname",
    "labelfontsize",
    "labelhref",
    "labeltarget",
    "labeltooltip",
    "layer",
    "len",
    "lhead",
    "lp",
    "ltail",
    "minlen",
    "nojustify",
    "pos",
    "samehead",
    "sametail",
    "showboxes",
    "style",
    "tailURL",
    "tailclip",
    "tailhref",
    "taillabel",
    "tailport",
    "tailtarget",
    "tailtooltip",
    "target",
    "tooltip",
    "weight"
  ]
end
